;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; pots/trig.tf ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;    Trigger for Abelinc's POTS Scripts for Aardwolf's Tinyfugue users    ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  03/06/2008  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; POTS Files   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; edit_variable.tf
;;; holds the macros to check, set, and write to file POTS, level, and classes
;;; note not within pots directory. This is because I am also releasing
;;; a spellup script which uses my_level
;;;
;;; pots/pots.tf
;;; holds the actual macros to buy and then use the pots of appropriate level
;;;
;;; pots/trig.tf
;;; holds the triggers for checking current pot inventories
;;;
;;; variables.tf holds which classes I have, my level, and number of POTS
;;; NOTE! not within pots directory. This is because I am also releasing
;;; a spellup script which uses my_level (and many other variables)
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; END POTS Files  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

/def -ag -hredef redef
;;;
;;; get my_level
;;;

/require variables.tf

/def do_heal_count_up = /test $[++heal_pots]
/def do_heal_count_down = /test $[--heal_pots]

/def do_mana_count_up = /test $[++mana_pots]
/def do_mana_count_down = /test $[--mana_pots]

/def do_move_count_up = /test $[++move_pots]
/def do_move_count_down = /test $[--move_pots]

/def do_web_count_up = /test $[++web_pots]
/def do_web_count_down = /test $[--web_pots]


;;;
;;; Decide which pots to watch events for
;;;

/set heal_pot_long=Just a Placeholder
/set mana_pot_long=Just a Placeholder
/set move_pot_long=Just a Placeholder
/set web_pot_long=Just a Placeholder

/if (effective_level<20) /exit %; \
/elseif (effective_level>=20 & effective_level<30) \
	/set mana_pot_name=Cheesy Nachos %; \
	/set heal_pot_name=Proclamation of Scathach %; \
	/set mana_pot_long=Cheesy Nachos [[]20[]] %; \
	/set heal_pot_long=Proclamation of Scathach [[]20[]] %; \
/endif


/if (effective_level>=30 & effective_level<40) \
	/set heal_pot_name=Dictionary %; \
	/set heal_pot_long=Dictionary( [[]30[]])? %; \
/endif

/if (effective_level>=30 & effective_level<60) \
	/set mana_pot_name=a Study Aid %; \
	/set mana_pot_long=a Study Aid( [(]30[)])? %; \
/endif

/if (effective_level>=40 & effective_level<60) \
	/set heal_pot_name=Soothing Melody %; \
	/set heal_pot_long=Soothing Melody( [(]40[)])? %; \
	/set mana_pot_name=Meditation %; \
	/set mana_pot_long=Meditation( [(]40[)])? %; \
/endif

/if ((effective_level>=60)&(cheap_heal=~"N")) \
	/set heal_pot_name=Healer's Ballad %; \
	/set heal_pot_long=Healer[']s Ballad( [(]60[)])? %; \
/endif

/if ((effective_level>=60)&(cheap_heal=~"Y")) \
	/set heal_pot_name=Elixer of a Prehistoric Earthworm %; \
	/set heal_pot_long=Elixer of a Prehistoric Earthworm( [(]60[)])? %; \
/endif

/if (effective_level>=60 & effective_level<80) \
	/set mana_pot_name=Green Herbal Tea %; \
	/set mana_pot_long=Green Herbal Tea( [(]60[)])? %; \
/endif

/if ((effective_level>=80 & effective_level<100)&(just_mana=~"N")) \
	/set mana_pot_name=Granny's Special Brew %; \
	/set mana_pot_long=Granny[']s Special Brew( [(]80[)])? %; \
/endif

;;;
;;;
;;; Gotta remember Romani's Level 80 mana pot
;;;
;;;

/if ((effective_level>=80 & effective_level<100)&(just_mana=~"Y")) \
	/set mana_pot_name=Trandorfir Pani ---'---,\\{@ %; \
	/set mana_pot_long=Trandorfir Pani ---[']---,\{@( [(]80[)])? %; \
/endif

/if (effective_level>=100) \
	/set move_pot_name=Song of the Traveller %; \
	/set move_pot_long=Song of the Traveller( [(]100[)])? %; \
/endif

/if (effective_level>=100 & effective_level<120) \
	/set mana_pot_name=Taboo's Energy Bar %; \
	/set mana_pot_long=Taboo[']s Energy Bar( [(]100[)])? %; \
/endif

/if (effective_level>=120 & effective_level<130) \
	/set mana_pot_name=Apple Squishie %; \
	/set mana_pot_long=Apple Squishie( [(]120[)])? %; \
/endif

/if (effective_level>=130 & effective_level<150) \
	/set mana_pot_name=Bag o' Buttery Showtime Popcorn %; \
	/set mana_pot_long=Bag o['] Buttery Showtime Popcorn( [(]130[)])? %; \
/endif

/if (effective_level>=150 & effective_level<180) \
	/set mana_pot_name=Ancestral Power %; \
	/set mana_pot_long=Ancestral Power( [(]150[)])? %; \
/endif

/if (effective_level>=180 & effective_level<201) \
	/set mana_pot_name=Prosperity %; \
	/set mana_pot_long=Prosperity( [(]180[)])? %; \
/endif

/if (effective_level>=201) \
	/set mana_pot_name=Moonlight Wine %; \
	/set mana_pot_long=Moonlight Wine( [(]201[)])? %; \
	/set web_pot_name=Departure %; \
	/set web_pot_long=Departure( [(]200[)])? %; \
/endif



/set pot_flags=([(]Magic[)] )?([(]M[)])?([(]Glow[)] )?([(]G[)])?([(]Hum[)] )?([(]H[)])? ?

/eval /def -mglob -t"You put $[mana_pot_name] into $[pots_bag]." mana_count_up = /do_mana_count_up
/eval /def -mglob -t"You get $[mana_pot_name] from $[pots_bag]." mana_count_down = /do_mana_count_down
/eval /def -p1 -F -mregexp -t"[(]([ ])?([0-9]+)[)] $[pot_flags]$[mana_pot_long]" mana_count_correct = /set mana_pots=%%P2

/eval /def -mglob -t"You put $[heal_pot_name] into $[pots_bag]." heal_count_up = /do_heal_count_up
/eval /def -mglob -t"You get $[heal_pot_name] from $[pots_bag]." heal_count_down = /do_heal_count_down
/eval /def -p1 -F -mregexp -t"[(]([ ])?([0-9]+)[)] $[pot_flags]$[heal_pot_long]" heal_count_correct = /set heal_pots=%%P2

/eval /def -mglob -t"You put $[move_pot_name] into $[pots_bag]." move_count_up = /do_move_count_up
/eval /def -mglob -t"You get $[move_pot_name] from $[pots_bag]." move_count_down = /do_move_count_down
/eval /def -p1 -F -mregexp -t"[(]([ ])?([0-9]+)[)] $[pot_flags]$[move_pot_long]" move_count_correct = /set move_pots=%%P2

/eval /def -mglob -t"You put $[web_pot_name] into $[pots_bag]." web_count_up = /do_web_count_up
/eval /def -mglob -t"You get $[web_pot_name] from $[pots_bag]." web_count_down = /do_web_count_down
/eval /def -p1 -F -mregexp -t"[(]([ ])?([0-9]+)[)] $[pot_flags]$[web_pot_long]" web_count_correct = /set web_pots=%%P2

/undef redef
